@@ -64,10 +64,14 @@
 #' whether argument \code{pattern} has 2 or 3 unique values and computes the correct structure of
 #' a given subject. The variable is cast as character;\cr
 #' \emph{status_num}: the corresponding integer version of \emph{status};\cr
-#' \emph{n_status}: a mix of \emph{status} and \emph{status_num} cast as character.
-#' \emph{status_num} comes into play when a model on the progression of the process is intended.\cr
+#' \emph{n_status}: a mix of \emph{status} and \code{n_events} cast as character.
+#' \emph{n_status} comes into play when a model on the progression of the process is intended.\cr
 #' -----\cr
 #'
+#' If \code{more_status} is passed, then \code{augment} computes some more variables. They mimic the
+#' meaning of \emph{status}, \emph{status_num}, and \emph{n_status} but they account for the more
+#' complex structure defined. They are: \code{status_exp}, \code{status_exp_num}, and
+#' \code{n_status_exp}.
 #' @examples
 #' # 1.
 #' # loading data
@@ -245,33 +249,32 @@ augment = function( data, data_key, n_events, pattern, state = list ( 'IN', 'OUT
     cat( '---\n' )
     if ( inherits( eval( substitute( unique( data$pattern ) ) ), 'integer' ) ||
          inherits( eval( substitute( unique( data$pattern ) ) ), 'numeric' ) ) {
-      match1 = data[ get( pattern ) == 0, .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
+      match1 = data[ data[ get( pattern ) == 0, .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
       if ( missing( t_death ) ) {
-        match3 = data[ get( pattern ) == 1,
-                       .SD[ .N ], by = eval( cols[[ 1 ]] ) ][ get( t_end ) != get( t_cens ) ]
+        match3 = data[ data[ get( pattern ) == 1,
+                             .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ][ get( t_end ) != get( t_cens ) ]
       } else {
-        match3 = data[ get( pattern ) == 1,
-                       .SD[ .N ], by = eval( cols[[ 1 ]] ) ][ get( t_end ) != get( t_death ) ]
+        match3 = data[ data[ get( pattern ) == 1,
+                             .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ][ get( t_end ) != get( t_death ) ]
       }
     } else if ( inherits( eval( substitute( unique( data$pattern ) ) ), 'factor' ) ) {
-      match1 = data[ as.integer( get( pattern ) ) - 1 == 0,
-                     .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
+      match1 = data[ data[ as.integer( get( pattern ) ) - 1 == 0,
+                           .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
       if ( missing( t_death ) ) {
-        match3 = data[ as.integer( get( pattern ) ) - 1 == 1,
-                       .SD[ .N ], by = eval( cols[[ 1 ]] ) ][ get( t_end ) != get( t_cens ) ]
+        match3 = data[ data[ as.integer( get( pattern ) ) - 1 == 1,
+                             .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ][ get( t_end ) != get( t_cens ) ]
       } else {
-        match3 = data[ as.integer( get( pattern ) ) - 1 == 1,
-                       .SD[ .N ], by = eval( cols[[ 1 ]] ) ][ get( t_end ) != get( t_death ) ]
+        match3 = data[ data[ as.integer( get( pattern ) ) - 1 == 1,
+                             .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ][ get( t_end ) != get( t_death ) ]
       }
     } else if ( inherits( eval( substitute( unique( data$pattern ) ) ), 'character' ) ) {
-      match1 = data[ get( pattern ) == values[ 1 ],
-                     .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
+      match1 = data[ data[ get( pattern ) == values[ 1 ], .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
       if ( missing( t_death ) ) {
-        match3 = data[ get( pattern ) == values[ 2 ],
-                       .SD[ .N ], by = eval( cols[[ 1 ]] ) ][ get( t_end ) != get( t_cens ) ]
+        match3 = data[ data[ get( pattern ) == values[ 2 ],
+                             .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ][ get( t_end ) != get( t_cens ) ]
       } else {
-        match3 = data[ get( pattern ) == values[ 2 ],
-                       .SD[ .N ], by = eval( cols[[ 1 ]] ) ][ get( t_end ) != get( t_death ) ]
+        match3 = data[ data[ get( pattern ) == values[ 2 ],
+                             .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ][ get( t_end ) != get( t_death ) ]
       }
     }
   } else if ( length( values ) == 3 ) {
@@ -279,19 +282,16 @@ augment = function( data, data_key, n_events, pattern, state = list ( 'IN', 'OUT
     cat( '---\n' )
     if ( inherits( eval( substitute( unique( data$pattern ) ) ), 'integer' ) ||
          inherits( eval( substitute( unique( data$pattern ) ) ), 'numeric' ) ) {
-      match1 = data[ get( pattern ) == 0,
-                     .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
-      match3 = data[ get( pattern ) == 2,
-                     .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
+      match1 = data[ data[ get( pattern ) == 0, .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
+      match3 = data[ data[ get( pattern ) == 2, .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
     } else if ( inherits( eval( substitute( unique( data$pattern ) ) ), 'factor' ) ) {
-      match1 = data[ as.integer( get( pattern ) ) - 1 == 0,
-                     .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
-      match3 = data[ as.integer( get( pattern ) ) - 1 == 2,
-                     .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
+      match1 = data[ data[ as.integer( get( pattern ) ) - 1 == 0,
+                           .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
+      match3 = data[ data[ as.integer( get( pattern ) ) - 1 == 2,
+                           .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
     } else if ( inherits( eval( substitute( unique( data$pattern ) ) ), 'character' ) ) {
-
-      match1 = data[ get( pattern ) == values[ 1 ], .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
-      match3 = data[ get( pattern ) == values[ 3 ], .SD[ .N ], by = eval( cols[[ 1 ]] ) ]
+      match1 = data[ data[ get( pattern ) == values[ 1 ], .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
+      match3 = data[ data[ get( pattern ) == values[ 3 ], .I[ .N ], by = eval( cols[[ 1 ]] ) ]$V1 ]
     }
   }
   if ( verbose == TRUE ) {
@@ -309,33 +309,33 @@ augment = function( data, data_key, n_events, pattern, state = list ( 'IN', 'OUT
                                    j = unique( get( pattern ) ),
                                    t_end = max( get( t_end ) ),
                                    t_cens = max( get( t_cens ) ) ), by = eval( cols[[ 1 ]] ) ]
-      .i = dim( counter_events )[ 1 ]
+      s = dim( counter_events )[ 1 ]
       status_flag_temp = vector( mode = 'list', dim( counter_events )[ 1 ] )
     } else {
       counter_events = final[ , .( N = .N,
                                    j = unique( get( pattern ) ),
                                    t_end = max( get( t_end ) ),
                                    t_death = max( get( t_death ) ) ), by = eval( cols[[ 1 ]] ) ]
-      .i = dim( counter_events )[ 1 ]
+      s = dim( counter_events )[ 1 ]
       status_flag_temp = vector( mode = 'list', dim( counter_events )[ 1 ] )
     }
   } else if ( length( values ) == 3 ) {
     counter_events = data[ , .( N = .N,
                                 j = unique( get( pattern ) ) ), by = eval( cols[[ 1 ]] ) ]
-    .i = dim( counter_events )[ 1 ]
+    s = dim( counter_events )[ 1 ]
     status_flag_temp = vector( mode = 'list', dim( counter_events )[ 1 ] )
   }
   if ( verbose == TRUE ) {
     message( 'adding status flag' )
   }
   for ( i in seq_along( counter_events$N ) ) {
-    if ( .i > 10000 ) {
+    if ( s > 10000 ) {
       if ( i %% 5000 == 0 ) {
-        cat( '* * * iteration', i, 'of', .i, '\n' )
+        cat( '* * * iteration', i, 'of', s, '\n' )
       }
     } else {
       if ( i %% 1000 == 0 ) {
-        cat( '* * * iteration', i, 'of', .i, '\n' )
+        cat( '* * * iteration', i, 'of', s, '\n' )
       }
     }
     if ( length( values ) == 2 ) {
@@ -395,7 +395,7 @@ augment = function( data, data_key, n_events, pattern, state = list ( 'IN', 'OUT
   if ( verbose == TRUE ) {
     message( 'adding numeric status flag' )
   }
-  k = length( unique( final$status ) )
+  k = uniqueN( final$status )
   lev = unique( final$status )
   for ( i in 1:k ) {
     final[ status == lev[ i ], status_num := i ]
@@ -452,12 +452,12 @@ augment = function( data, data_key, n_events, pattern, state = list ( 'IN', 'OUT
          paste( substitute( t_augmented ), '_num', sep = '' ),
          '\" successfully added and repositioned\n', sep = '' )
     cat( '---\n' )
-  }
-  id_col = which( names( data ) == substitute( t_start ) )
-  setcolorder( final, c( 1:( id_col - 1 ), dim( final )[ 2 ],
-                         id_col:( dim( final )[ 2 ] - 1 ) ) )
-  if ( inherits( eval( substitute( data$t_start ) ), 'integer' ) ||
-       inherits( eval( substitute( data$t_start ) ), 'numeric' ) ) {
+  } else if ( inherits( eval( substitute( data$t_start ) ), 'integer' ) ||
+              inherits( eval( substitute( data$t_start ) ), 'numeric' ) ) {
+
+    id_col = which( names( data ) == substitute( t_start ) )
+    setcolorder( final, c( 1:( id_col - 1 ), dim( final )[ 2 ],
+                           id_col:( dim( final )[ 2 ] - 1 ) ) )
     cat( 'variable \"', substitute( t_augmented ),
          '\" successfully added and repositioned\n', sep = '' )
     cat( '---\n' )
@@ -492,7 +492,7 @@ augment = function( data, data_key, n_events, pattern, state = list ( 'IN', 'OUT
     if ( verbose == TRUE ) {
       message( 'adding numeric expanded status flag' )
     }
-    k = length( unique( final$status_exp ) )
+    k = uniqueN( final$status_exp )
     lev = unique( final$status_exp )
     for ( i in 1:k ) {
       final[ status_exp == lev[ i ], status_exp_num := i ]
